@@ -25,14 +25,15 @@
 #include "calls-main-window.h"
 #include "calls-origin.h"
 #include "calls-ussd.h"
-#include "calls-call-holder.h"
 #include "calls-call-selector-item.h"
 #include "calls-new-call-box.h"
+#include "calls-contacts-box.h"
 #include "calls-history-box.h"
 #include "calls-in-app-notification.h"
 #include "calls-manager.h"
 #include "config.h"
 #include "util.h"
+#include "version.h"
 
 #include <glib/gi18n.h>
 #include <glib-object.h>
@@ -214,7 +215,7 @@ window_ussd_respond_cb (GObject      *object,
 {
   CallsMainWindow *self = user_data;
   g_autofree char *response = NULL;
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GError) error = NULL;
   CallsUssd *ussd;
 
   ussd = g_object_get_data (G_OBJECT (self->ussd_dialog), "ussd");
@@ -261,7 +262,7 @@ main_window_ussd_send_cb (GObject      *object,
 {
   CallsMainWindow *self = user_data;
   g_autofree char *response = NULL;
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GError) error = NULL;
   CallsUssd *ussd;
 
   response = calls_new_call_box_send_ussd_finish (self->new_call, result, &error);
@@ -314,10 +315,14 @@ state_changed_cb (CallsMainWindow *self,
     case CALLS_MANAGER_STATE_READY:
       break;
 
-    case CALLS_MANAGER_STATE_NO_ORIGIN:
+    case CALLS_MANAGER_STATE_NO_VOICE_MODEM:
       error = _("Can't place calls: No voice-capable modem available");
       break;
 
+    case CALLS_MANAGER_STATE_NO_ORIGIN:
+      error = _("Can't place calls: No modem or VoIP account available");
+      break;
+
     case CALLS_MANAGER_STATE_UNKNOWN:
     case CALLS_MANAGER_STATE_NO_PROVIDER:
       error = _("Can't place calls: No backend service");
@@ -326,6 +331,9 @@ state_changed_cb (CallsMainWindow *self,
     case CALLS_MANAGER_STATE_NO_PLUGIN:
       error = _("Can't place calls: No plugin");
       break;
+
+    default:
+      g_assert_not_reached ();
     }
 
   gtk_label_set_text (self->permanent_error_label, error);
@@ -358,6 +366,15 @@ constructed (GObject *object)
                             self);
   gtk_window_set_transient_for (GTK_WINDOW (self->ussd_dialog), GTK_WINDOW (self));
 
+  // Add contacs box
+  widget = calls_contacts_box_new ();
+  gtk_stack_add_titled (self->main_stack, widget,
+                        "contacts", _("Contacts"));
+  gtk_container_child_set (main_stack, widget,
+                           "icon-name", "system-users-symbolic",
+                           NULL);
+  gtk_widget_set_visible (widget, TRUE);
+
   // Add new call box
   self->new_call = calls_new_call_box_new ();
   widget = GTK_WIDGET (self->new_call);
@@ -366,7 +383,6 @@ constructed (GObject *object)
   gtk_container_child_set (main_stack, widget,
                            "icon-name", "input-dialpad-symbolic",
                            NULL);
-
   // Add call records
   history = calls_history_box_new (self->record_store);
   widget = GTK_WIDGET (history);
